# bbprepared
A general toolkit for working with building blocks for construction of larger molecules.

The library is built off of [`stk`](https://stk.readthedocs.io/en/stable/), which comes with the pip install.

# Installation

`bbprepared` is a `pip` installable library:
 ```
 $ pip install bbprepared
 ```

The code can be also installed following these steps:

1. clone `bbprepared` from [here](https://github.com/andrewtarzia/bbprepared)

2. Create a `conda` or `mamba` environment:
 ```
 $ mamba create -n NAME python=3.11
 ```

3. Activate the environment:
 ```
$ conda activate NAME
```

5. From `bbprepared` directory, install pip environment:
```
$ pip install .
```
or for development,
```
$ pip install -e .
```


# Usage

* To be completed, but see tests for examples.

# Acknowledgements

This work is a mixture of codes developed throughout my postdoc in the [Jelfs Group](http://www.jelfs-group.org/), and the [Pavan Group](https://www.gmpavanlab.com/), and during my time as a developer of [`stk`](https://stk.readthedocs.io/en/stable/) and [`stko`](https://github.com/JelfsMaterialsGroup/stko) with Lukas Turcani.
